@@ -2,11 +2,10 @@
 mod opus_test;
 
 use crate::{
-    error::Error,
+    error::{Error, Result},
     packetizer::{Depacketizer, Payloader},
 };
 
-use anyhow::Result;
 use bytes::Bytes;
 
 #[derive(Default, Debug, Copy, Clone)]
@@ -28,17 +27,22 @@ impl Payloader for OpusPayloader {
 
 /// OpusPacket represents the Opus header that is stored in the payload of an RTP Packet
 #[derive(PartialEq, Debug, Default, Clone)]
-pub struct OpusPacket {
-    pub payload: Bytes,
-}
+pub struct OpusPacket;
 
 impl Depacketizer for OpusPacket {
-    fn depacketize(&mut self, packet: &Bytes) -> Result<()> {
+    fn depacketize(&mut self, packet: &Bytes) -> Result<Bytes> {
         if packet.is_empty() {
-            Err(Error::ErrShortPacket.into())
+            Err(Error::ErrShortPacket)
         } else {
-            self.payload = packet.clone();
-            Ok(())
+            Ok(packet.clone())
         }
     }
+
+    fn is_partition_head(&self, _payload: &Bytes) -> bool {
+        true
+    }
+
+    fn is_partition_tail(&self, _marker: bool, _payload: &Bytes) -> bool {
+        true
+    }
 }
