@@ -2,10 +2,10 @@
 mod vp9_test;
 
 use crate::{
-    error::Error,
+    error::{Error, Result},
     packetizer::{Depacketizer, Payloader},
 };
-use anyhow::Result;
+
 use bytes::{Buf, BufMut, Bytes, BytesMut};
 use std::fmt;
 use std::sync::Arc;
@@ -40,12 +40,12 @@ impl Payloader for Vp9Payloader {
     /// Payload fragments an Vp9Payloader packet across one or more byte arrays
     fn payload(&mut self, mtu: usize, payload: &Bytes) -> Result<Vec<Bytes>> {
         /*
-         * https://www.ietf.org/id/draft-ietf-payload-vp9-10.txt
+         * https://www.ietf.org/id/draft-ietf-payload-vp9-13.txt
          *
          * Flexible mode (F=1)
          *        0 1 2 3 4 5 6 7
          *       +-+-+-+-+-+-+-+-+
-         *       |I|P|L|F|B|E|V|-| (REQUIRED)
+         *       |I|P|L|F|B|E|V|Z| (REQUIRED)
          *       +-+-+-+-+-+-+-+-+
          *  I:   |M| PICTURE ID  | (REQUIRED)
          *       +-+-+-+-+-+-+-+-+
@@ -62,7 +62,7 @@ impl Payloader for Vp9Payloader {
          * Non-flexible mode (F=0)
          *        0 1 2 3 4 5 6 7
          *       +-+-+-+-+-+-+-+-+
-         *       |I|P|L|F|B|E|V|-| (REQUIRED)
+         *       |I|P|L|F|B|E|V|Z| (REQUIRED)
          *       +-+-+-+-+-+-+-+-+
          *  I:   |M| PICTURE ID  | (RECOMMENDED)
          *       +-+-+-+-+-+-+-+-+
@@ -70,7 +70,7 @@ impl Payloader for Vp9Payloader {
          *       +-+-+-+-+-+-+-+-+
          *  L:   | tid |U| SID |D| (CONDITIONALLY RECOMMENDED)
          *       +-+-+-+-+-+-+-+-+
-         *       |   TL0PICIDX   | (CONDITIONALLY REQUIRED)
+         *       |   tl0picidx   | (CONDITIONALLY REQUIRED)
          *       +-+-+-+-+-+-+-+-+
          *  V:   | SS            |
          *       | ..            |
@@ -158,6 +158,8 @@ pub struct Vp9Packet {
     pub e: bool,
     /// scalability structure (SS) present
     pub v: bool,
+    /// Not a reference frame for upper spatial layers
+    pub z: bool,
 
     /// Recommended headers
     /// 7 or 16 bits, picture ID.
@@ -196,15 +198,13 @@ pub struct Vp9Packet {
     pub pgu: Vec<bool>,
     /// Reference indecies of pictures in a Picture Group
     pub pgpdiff: Vec<Vec<u8>>,
-
-    pub payload: Bytes,
 }
 
 impl Depacketizer for Vp9Packet {
     /// depacketize parses the passed byte slice and stores the result in the Vp9Packet this method is called upon
-    fn depacketize(&mut self, packet: &Bytes) -> Result<()> {
+    fn depacketize(&mut self, packet: &Bytes) -> Result<Bytes> {
         if packet.is_empty() {
-            return Err(Error::ErrShortPacket.into());
+            return Err(Error::ErrShortPacket);
         }
 
         let reader = &mut packet.clone();
@@ -217,6 +217,7 @@ impl Depacketizer for Vp9Packet {
         self.b = (b & 0x08) != 0;
         self.e = (b & 0x04) != 0;
         self.v = (b & 0x02) != 0;
+        self.z = (b & 0x01) != 0;
 
         let mut payload_index = 1;
 
@@ -236,9 +237,20 @@ impl Depacketizer for Vp9Packet {
             payload_index = self.parse_ssdata(reader, payload_index)?;
         }
 
-        self.payload = packet.slice(payload_index..);
+        Ok(packet.slice(payload_index..))
+    }
 
-        Ok(())
+    /// is_partition_head checks whether if this is a head of the VP9 partition
+    fn is_partition_head(&self, payload: &Bytes) -> bool {
+        if payload.is_empty() {
+            false
+        } else {
+            (payload[0] & 0x08) != 0
+        }
+    }
+
+    fn is_partition_tail(&self, marker: bool, _payload: &Bytes) -> bool {
+        marker
     }
 }
 
@@ -257,14 +269,14 @@ impl Vp9Packet {
         mut payload_index: usize,
     ) -> Result<usize> {
         if reader.remaining() == 0 {
-            return Err(Error::ErrShortPacket.into());
+            return Err(Error::ErrShortPacket);
         }
         let b = reader.get_u8();
         payload_index += 1;
         // PID present?
         if (b & 0x80) != 0 {
             if reader.remaining() == 0 {
-                return Err(Error::ErrShortPacket.into());
+                return Err(Error::ErrShortPacket);
             }
             // M == 1, PID is 15bit
             self.picture_id = (((b & 0x7f) as u16) << 8) | (reader.get_u8() as u16);
@@ -302,7 +314,7 @@ impl Vp9Packet {
         mut payload_index: usize,
     ) -> Result<usize> {
         if reader.remaining() == 0 {
-            return Err(Error::ErrShortPacket.into());
+            return Err(Error::ErrShortPacket);
         }
         let b = reader.get_u8();
         payload_index += 1;
@@ -313,7 +325,7 @@ impl Vp9Packet {
         self.d = b & 0x01 != 0;
 
         if self.sid >= MAX_SPATIAL_LAYERS {
-            Err(Error::ErrTooManySpatialLayers.into())
+            Err(Error::ErrTooManySpatialLayers)
         } else {
             Ok(payload_index)
         }
@@ -333,7 +345,7 @@ impl Vp9Packet {
         mut payload_index: usize,
     ) -> Result<usize> {
         if reader.remaining() == 0 {
-            return Err(Error::ErrShortPacket.into());
+            return Err(Error::ErrShortPacket);
         }
         self.tl0picidx = reader.get_u8();
         payload_index += 1;
@@ -355,14 +367,14 @@ impl Vp9Packet {
         let mut b = 1u8;
         while (b & 0x1) != 0 {
             if reader.remaining() == 0 {
-                return Err(Error::ErrShortPacket.into());
+                return Err(Error::ErrShortPacket);
             }
             b = reader.get_u8();
             payload_index += 1;
 
             self.pdiff.push(b >> 1);
             if self.pdiff.len() >= MAX_VP9REF_PICS {
-                return Err(Error::ErrTooManyPDiff.into());
+                return Err(Error::ErrTooManyPDiff);
             }
         }
 
@@ -391,7 +403,7 @@ impl Vp9Packet {
     //
     fn parse_ssdata(&mut self, reader: &mut dyn Buf, mut payload_index: usize) -> Result<usize> {
         if reader.remaining() == 0 {
-            return Err(Error::ErrShortPacket.into());
+            return Err(Error::ErrShortPacket);
         }
 
         let b = reader.get_u8();
@@ -406,7 +418,7 @@ impl Vp9Packet {
 
         if self.y {
             if reader.remaining() < 4 * ns {
-                return Err(Error::ErrShortPacket.into());
+                return Err(Error::ErrShortPacket);
             }
 
             self.width = vec![0u16; ns];
@@ -420,7 +432,7 @@ impl Vp9Packet {
 
         if self.g {
             if reader.remaining() == 0 {
-                return Err(Error::ErrShortPacket.into());
+                return Err(Error::ErrShortPacket);
             }
 
             self.ng = reader.get_u8();
@@ -429,7 +441,7 @@ impl Vp9Packet {
 
         for i in 0..self.ng as usize {
             if reader.remaining() == 0 {
-                return Err(Error::ErrShortPacket.into());
+                return Err(Error::ErrShortPacket);
             }
             let b = reader.get_u8();
             payload_index += 1;
@@ -439,7 +451,7 @@ impl Vp9Packet {
 
             let r = ((b >> 2) & 0x3) as usize;
             if reader.remaining() < r {
-                return Err(Error::ErrShortPacket.into());
+                return Err(Error::ErrShortPacket);
             }
 
             self.pgpdiff.push(vec![]);
@@ -454,18 +466,3 @@ impl Vp9Packet {
         Ok(payload_index)
     }
 }
-
-/// Vp9PartitionHeadChecker checks VP9 partition head
-pub struct Vp9PartitionHeadChecker;
-
-impl Vp9PartitionHeadChecker {
-    /// is_partition_head checks whether if this is a head of the VP9 partition
-    pub fn is_partition_head(packet: &Bytes) -> bool {
-        let mut p = Vp9Packet::default();
-        if p.depacketize(packet).is_err() {
-            false
-        } else {
-            p.b
-        }
-    }
-}
