@@ -4,7 +4,6 @@ mod audio_level_extension_test;
 use crate::error::Error;
 use util::marshal::{Marshal, MarshalSize, Unmarshal};
 
-use anyhow::Result;
 use bytes::{Buf, BufMut};
 
 // AUDIO_LEVEL_EXTENSION_SIZE One byte header size
@@ -37,7 +36,7 @@ pub struct AudioLevelExtension {
 
 impl Unmarshal for AudioLevelExtension {
     /// Unmarshal parses the passed byte slice and stores the result in the members
-    fn unmarshal<B>(raw_packet: &mut B) -> Result<Self>
+    fn unmarshal<B>(raw_packet: &mut B) -> Result<Self, util::Error>
     where
         Self: Sized,
         B: Buf,
@@ -64,7 +63,7 @@ impl MarshalSize for AudioLevelExtension {
 
 impl Marshal for AudioLevelExtension {
     /// MarshalTo serializes the members to buffer
-    fn marshal_to(&self, mut buf: &mut [u8]) -> Result<usize> {
+    fn marshal_to(&self, mut buf: &mut [u8]) -> Result<usize, util::Error> {
         if buf.remaining_mut() < AUDIO_LEVEL_EXTENSION_SIZE {
             return Err(Error::ErrBufferTooSmall.into());
         }
